# Project Description

# Release History 

## version==0.0.28   
包裹管理中给前端用的快递公司 ZTO

## version==0.0.26   
首单礼需求  
gift_type    

## version==0.0.25   
退货重算功能  
BaseModelTimeAndDeleted    

## version==0.0.24   
退货重算功能  
AfsVlinesPointsCharge  
AfsVlinesOnlyRefundPoint  

## version==0.0.23  
退货重算功能  
AfsVersionSuite  

## version==0.0.22  
退货重算功能  
AfsVersionSuite  

## version==0.0.21  
退货重算功能  
AfsVersionSuite  


## version==0.0.20  
退货重算功能  


## version==0.0.19  
从揽月获取用户信息  


## version==0.0.18  
退货重算相关 models  


## version==0.0.17  
sparrow_parcel 箱体相关 models  


## version==0.0.19
从揽月获取用户信息

## version==0.0.18
物料管理 增加seq排序属性

## version==0.0.17
物料管理相关models

## version==0.0.16
发货单相关 models 操作添加角色相关信息  
core 内新增对方法运行结果缓存的装饰器  
清除所有环境变量  


## version==0.0.15
AfsHgIncomeDivide修改字段 divide_payment_type 类型为 int -> char  

## version==0.0.14
AfsHgIncomeDivide新增字段payment_num  


## version==0.0.13
AfsHgIncomeDevide改名为AfsHgIncomeDivide  
AfsHgIncomeDivide新增字段hgincome_type_id  
  
## version==0.0.12
sparrow_aftersale_afs 新增字段afs_sync_status, afs_sync_time  
新增两个model： AfsHgIncome & AfsHgIncomeDevide  

## version==0.0.11
修复包裹管理中文案错误  
添加包裹管理中 BulkEvent

## version==0.0.10
删掉不必要通过环境变量赋值的常量  
现将前面几个版本所需环境变量整理如下:  
```
RUN_ENV

settings 里面需要添加以下配置, 也可设置为环境变量  
SF_PAYCARD_NUMBER_MAILE
SHIPPING_URL_SF_USERCODE
SHIPPING_URL_SF_CHECKCODE
SF_PAYCARD_NUMBER_HANGUANG
SHIPPING_CREATE_ORDER_SENDER_NO_YZPY
SHIPPING_CREATE_ORDER_ECOMMERCE_NO_YZPY
SHIPPING_CREATE_ORDER_ECCOMPANYID_YZPY
SHIPPING_CREATE_ORDER_SECRET_YZPY
```

## version==0.0.9
为所有 APP_LABEL 设置默认值  

## version==0.0.8
sparrow_parcel 的 Transfer 实体去掉揽收包裹数量字段  

## version==0.0.7
修改一些bug  

## version==0.0.6
将 sparrow_shipping 维护至本项目  
将 remote_call 维护至本项目
```
需要新增以下环境变量
RUN_ENV
export SPARROW_ORDER_APP_LABEL=sparrow_orders
export SPARROW_ORDER_AFS_APP_LABEL=sparrow_orders_afs
export SPARROW_DISTRIBUTE_APP_LABEL=sparrow_distribute
export SPARROW_AFTERSALE_APP_LABEL=sparrow_aftersale
export SPARROW_EXCHANGE_APP_LABEL=sparrow_exchange
export SPARROW_PROMOTIONS_APP_LABEL=sparrow_promotions
export SPARROW_DISSTORAGE_APP_LABEL=sparrow_disstorage
export SPARROW_PARCEL_APP_LABEL=sparrow_parcel
export SPARROW_SHIPPING_APP_LABEL=sparrow_shipping
SC_SPARROW_CORE_GO_SVC
SC_SPARROW_CORE_SVC
SC_SPARROW_PRODUCT_SVC

settings 里面需要添加以下配置
SF_PAYCARD_NUMBER_MAILE
SHIPPING_URL_SF_USERCODE
SHIPPING_URL_SF_CHECKCODE
SF_PAYCARD_NUMBER_HANGUANG
SHIPPING_CREATE_ORDER_SENDER_NO_YZPY
SHIPPING_CREATE_ORDER_ECOMMERCE_NO_YZPY
SHIPPING_CREATE_ORDER_ECCOMPANYID_YZPY
SHIPPING_CREATE_ORDER_SECRET_YZPY
```

## version==0.0.5
############# sparrow-order-lib 使用配置 ############
export SPARROW_ORDER_APP_LABEL=sparrow_orders
export SPARROW_ORDER_AFS_APP_LABEL=sparrow_orders_afs
export SPARROW_DISTRIBUTE_APP_LABEL=sparrow_distribute
export SPARROW_AFTERSALE_APP_LABEL=sparrow_aftersale
export SPARROW_EXCHANGE_APP_LABEL=sparrow_exchange
export SPARROW_PROMOTIONS_APP_LABEL=sparrow_promotions
export SPARROW_DISSTORAGE_APP_LABEL=sparrow_disstorage
export SPARROW_PARCEL_APP_LABEL=sparrow_parcel

## version==0.0.4
将 sparrow_disstorage 维护至本项目  
新增项目 sparrow_parcel  
该版本尝试将 exceptions 维护至本项目  
```
需要新增以下环境变量
SPARROW_DISSTORAGE_APP_LABEL
SPARROW_PARCEL_APP_LABEL
```

## version==0.03
将所有公共 models 维护至本项目。
```
需要以下环境变量:  
SPARROW_ORDER_APP_LABEL
SPARROW_ORDER_AFS_APP_LABEL
SPARROW_DISTRIBUTE_APP_LABEL  
SPARROW_AFTERSALE_APP_LABEL
SPARROW_EXCHANGE_APP_LABEL
SPARROW_PROMOTIONS_APP_LABEL
```

settings 要包含以下配置
```
PHONE_NUMBER_REGEX
```

## version==0.02
测试 models 维护至 sparrow-order-lib 可行性

## version==0.01
core.db_tool.query
